@@ -55,7 +55,7 @@ from lfmaptools.utilities import (_nice_round,
                                   csv_active_cols,
                                   csv_num_cols,
                                   _decompress_gz)
-from lfmaptools.netcdf_utils import nc2np, nc_max, nc_min
+from lfmaptools.netcdf_utils import nc2np, nc_max, nc_min, nc_min_max
 from lfmaptools.geotools import LatLon_TM_polygonize, LatLon_TM
 from lfmaptools.epsg_defs import webmerc, wgs84
 from lfmaptools.mapping import add_stamen_basemap
@@ -246,10 +246,14 @@ class LaharFlowData(object):
                 self._get_parameters_from_inputfile()
             else:
                 self._get_parameters_from_runinfo()
-            self._get_max_depth()
-            self._get_max_speed()
-            self._get_max_conc()
-            self._get_max_bed_evolution()
+            
+            if ('Maximums.nc' in self.nc_files):
+                self._get_nc_max()
+            else:
+                self._get_max_depth()
+                self._get_max_speed()
+                self._get_max_conc()
+                self._get_max_bed_evolution()
     
     def _get_parameters_from_inputfile(self):
         if self.zipped:
@@ -991,6 +995,37 @@ class LaharFlowData(object):
             bt = bt.where(bt.data<vmax)
         
         return bt
+    
+    def _get_nc_max(self):
+        LaharFlowFile = self._extract_file('Maximums.nc')
+        try:
+            m = nc_max(LaharFlowFile)
+            self.MaxDepth = m['maximum_depth']
+            self.MaxSpeed = m['maximum_speed']
+            self.MaxConc = m['maximum_concentration']
+        except:
+            self.MaxDepth = None
+            self.MaxSpeed = None
+            self.MaxConc = None
+        
+        last_outfile = self.get_snapshot_files()[-1]
+        try:
+            maxE, maxD = nc_min_max(last_outfile, var='elevation_change')
+            self.MaxDeposit = maxD['elevation_change']
+            self.MaxErosion = -maxE['elevation_change']
+        except:
+            self.MaxDeposit = None
+            self.MaxErosion = None
+        return
+
+    def _get_max_erosion(self):
+        
+        last_outfile = self.get_snapshot_files()[-1]
+        _, _, bt = self._get_data_column(last_outfile, 14)
+        
+        self.MaxErosion = max(-np.amin(bt),0.0)
+
+        return
 
     def _get_max_conc(self):
         
@@ -998,9 +1033,9 @@ class LaharFlowData(object):
             LaharFlowFile = self._extract_file('Maximums.nc')
             try:
                 m = nc_max(LaharFlowFile, 'maximum_concentration')
-                self.MaxConc = m['maximum_depth']
+                self.MaxConc = m['maximum_concentration']
             except:
-                self.MaxConc = None            
+                self.MaxConc = None
             return
         else:
             print ('make this work')
