@@ -120,4 +120,33 @@ def nc_min(filename, var=None):
             for v in variables:
                 min_vals[v] = min(min_vals[v], np.amin(grp[v][:]))
 
-    return min_vals
\ No newline at end of file
+    return min_vals
+
+def nc_min_max(filename, var=None):
+
+    with nc.Dataset(filename, 'r') as rgrp:
+
+        tiles = list(rgrp.groups)
+
+        nc_variables = list(rgrp[tiles[0]].variables)
+
+        if var is None:
+            variables = nc_variables.copy()
+        else:
+            if isinstance(var, list):
+                variables = [v for v in var if v in nc_variables]
+            else:
+                if var in nc_variables:
+                    variables = [var] 
+                else:
+                    raise ValueError('variable {} not in netcdf file {}'.format(var, filename))
+        min_vals = dict.fromkeys(variables, np.inf)
+        max_vals = dict.fromkeys(variables, -np.inf)
+
+        for t in tiles:
+            grp = rgrp[t]
+            for v in variables:
+                min_vals[v] = min(min_vals[v], np.amin(grp[v][:]))
+                max_vals[v] = max(max_vals[v], np.amax(grp[v][:]))
+
+    return min_vals, max_vals
\ No newline at end of file
